@@ -22,6 +22,7 @@ from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
                                     ReadonlyTableVariable, FieldValue,
                                     HumanReadable)
 from calculate.lib.cl_ini_parser import iniParser
+from calculate.lib.configparser import ConfigParser
 import calculate.lib.utils.device as device
 from calculate.lib.utils.files import (readFile, find,
                                        FindFileType)
@@ -38,6 +39,7 @@ from calculate.lib.cl_ldap import ldapUser
 from calculate.lib.variables.user import LdapHelper
 import pwd
 from calculate.client.client import Client
+from calculate.client.rsync import ProfileSyncer, ProfileSyncerError
 
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 
@@ -631,6 +633,49 @@ class SyncHelper(object):
             return False
         return True
 
+    def getSyncDate(self, osLinuxShort, ps):
+        """
+        Получить время синхронизации из ::profile/.calculate/desktop.env
+        """
+        desktopEnvRemoteData = ps.readfile("::profile/{}/{}".format(
+            osLinuxShort, Client.configFileDesktop))
+        if desktopEnvRemoteData:
+            cpRemote = ConfigParser(strict=False)
+            cpRemote.read_string(desktopEnvRemoteData)
+            timeLogout = cpRemote.get("main", "date_logout", fallback=None)
+            timeConfig = cpRemote.get("main", "date", fallback=None)
+            dates = filter(None,
+                           [self.convertDate(timeLogout),
+                            self.convertDate(timeConfig)])
+            if dates:
+                return dates[0]
+        return ""
+
+
+    def checkNeedSyncNew(self, homeDir, rpath, curTimeObj, curStatusSync,
+                      osLinuxShort, ps):
+        """
+        Проверить необходимость синхронизации текущего профиля с удаленным
+        """
+        iniEnvRemoteData = ps.readfile("::profile/{}/{}".format(
+            osLinuxShort, Client.configFileSoft))
+        fileConfigCur = os.path.join(homeDir, Client.configFileSoft)
+        iniEnvCurrentData = readFile(fileConfigCur)
+        cpCur = ConfigParser(strict=False)
+        cpCur.read_string(iniEnvCurrentData)
+        cpRemote = ConfigParser(strict=False)
+        cpRemote.read_string(iniEnvRemoteData)
+
+        xSessionCur = cpCur.get('main', 'xsession', fallback=None)
+        xSessionThis = cpThis.get('main', 'xsession', fallback=None)
+        if curStatusSync == "success_logout" and \
+                        xSessionCur == xSessionThis:
+            thisTimeObj = self.getSyncDate(osLinuxShort, ps)
+            if thisTimeObj and curTimeObj and \
+                        curTimeObj >= thisTimeObj:
+                return False
+        return True
+
 
 class VariableClClientSyncTime(SyncHelper, ReadonlyVariable):
     """
@@ -672,18 +717,27 @@ class VariableClClientLocalSyncTime(SyncHelper, ReadonlyVariable):
                             limit=1), self.Get('cl_client_profile_name')))
 
 
+class VariableClClientRsyncProfileSet(ReadonlyVariable):
+    """
+    Используется rsync через ssh для синхронизации пользовательского профиля
+    """
+    type = "bool"
+    value = "off"
+
+
 class VariableClClientSyncReplicationSet(SyncHelper, ReadonlyVariable):
     """
     Нужно ли синхронизировать текущий профиль с удаленным доменом
     """
     type = "bool"
 
-    def get(self):
-        if not self.Get('cl_replication_host'):
-            return "off"
+    host_varname = "cl_replication_host"
+    profile_type = "remote_profile"
+
+    def old_synchronize(self):
         profilePath = self.Select('cl_client_user_mount_path',
                                   where='cl_client_user_mount_name',
-                                  eq='remote_profile', limit=1)
+                                  eq=self.profile_type, limit=1)
         if self.Get('cl_action') == 'login' and not isMount(profilePath):
             raise VariableError(_("Remote profile not mounted"))
         return "on" if self.checkNeedSync(self.Get('ur_home_path'), profilePath,
@@ -692,26 +746,39 @@ class VariableClClientSyncReplicationSet(SyncHelper, ReadonlyVariable):
                                           self.Get(
                                               'cl_client_profile_name')) else "off"
 
+    def new_synchronize(self):
+        user = self.Get('ur_login')
+        pwd = self.Get('desktop.ur_password')
+        remotehost = self.Get(self.host_varname)
+        ps =  ProfileSyncer(remotehost, 2009, user, pwd)
 
-class VariableClClientSyncLocalSet(SyncHelper, ReadonlyVariable):
+        if ps.check():
+            return "on" if self.checkNeedSyncNew(
+                self.Get('ur_home_path'), profilePath,
+                self.Get('cl_client_sync_time'),
+                self.Get('cl_client_sync_status'),
+                self.Get('cl_client_profile_name'),
+                ps) else "off"
+        return "off"
+
+    def get(self):
+        if not self.Get(self.host_varname):
+            return "off"
+
+        if self.GetBool('cl_client_rsync_profile_set'):
+            return self.new_synchronize()
+        else:
+            return self.old_synchronize()
+
+
+class VariableClClientSyncLocalSet(VariableClClientSyncReplicationSet):
     """
     Нужно ли синхронизировать текущий профиль с локальным доменом
     """
     type = "bool"
 
-    def get(self):
-        if not self.Get('cl_remote_host'):
-            return "off"
-        profilePath = self.Select('cl_client_user_mount_path',
-                                  where='cl_client_user_mount_name',
-                                  eq='unix', limit=1)
-        if self.Get('cl_action') == 'login' and not isMount(profilePath):
-            raise VariableError(_("Remote profile not mounted"))
-        return "on" if self.checkNeedSync(self.Get('ur_home_path'), profilePath,
-                                          self.Get('cl_client_sync_time'),
-                                          self.Get('cl_client_sync_status'),
-                                          self.Get(
-                                              'cl_client_profile_name')) else "off"
+    host_varname = "cl_remote_host"
+    profile_type = "unix"
 
 
 class VariableClClientSymlinks(ReadonlyVariable):
